==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/uibuilder/property/renderer/NlXmlRenderers.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.uibuilder.property.renderer;

import com.android.tools.adtui.ptable.PNameRenderer;
import com.android.tools.adtui.ptable.PTableCellRendererProvider;
import com.android.tools.adtui.ptable.PTableItem;
import org.jetbrains.annotations.NotNull;

import javax.swing.table.TableCellRenderer;

public class NlXmlRenderers implements PTableCellRendererProvider {
  private static NlXmlRenderers ourInstance = new NlXmlRenderers();

  private final NlXmlNameRenderer myXmlNameRenderer;
  private final NlXmlValueRenderer myXmlValueRenderer;

  public static NlXmlRenderers getInstance() {
    if (ourInstance == null) {
      ourInstance = new NlXmlRenderers();
    }
    return ourInstance;
  }

  private NlXmlRenderers() {
    myXmlNameRenderer = new NlXmlNameRenderer();
    myXmlValueRenderer = new NlXmlValueRenderer();
  }

  @NotNull
  @Override
  public PNameRenderer getNameCellRenderer(@NotNull PTableItem item) {
    return myXmlNameRenderer;
  }

  @NotNull
  @Override
  public TableCellRenderer getValueCellRenderer(@NotNull PTableItem item) {
    return myXmlValueRenderer;
  }
}

==> ideaIC-2019.3.5-sources.jar: com/android/tools/idea/uibuilder/property/renderer/NlXmlRenderers.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.uibuilder.property.renderer;

import com.android.tools.property.ptable.PNameRenderer;
import com.android.tools.property.ptable.PTableCellRendererProvider;
import com.android.tools.property.ptable.PTableItem;
import org.jetbrains.annotations.NotNull;

import javax.swing.table.TableCellRenderer;

public class NlXmlRenderers implements PTableCellRendererProvider {
  private static NlXmlRenderers ourInstance = new NlXmlRenderers();

  private final NlXmlNameRenderer myXmlNameRenderer;
  private final NlXmlValueRenderer myXmlValueRenderer;

  public static NlXmlRenderers getInstance() {
    if (ourInstance == null) {
      ourInstance = new NlXmlRenderers();
    }
    return ourInstance;
  }

  private NlXmlRenderers() {
    myXmlNameRenderer = new NlXmlNameRenderer();
    myXmlValueRenderer = new NlXmlValueRenderer();
  }

  @NotNull
  @Override
  public PNameRenderer getNameCellRenderer(@NotNull PTableItem item) {
    return myXmlNameRenderer;
  }

  @NotNull
  @Override
  public TableCellRenderer getValueCellRenderer(@NotNull PTableItem item) {
    return myXmlValueRenderer;
  }
}
